@@ -449,7 +449,7 @@ regress_annotation_object_compute_sum_n(RegressAnnotationObject *object,
 /**
  * regress_annotation_object_compute_sum_nz:
  * @object: a #RegressAnnotationObject
- * @nums: (array length=n_nums zero-terminated=1): Sequence of numbers that
+ * @nums: (array length=n_nums zero-terminated): Sequence of numbers that
  * are zero-terminated
  * @n_nums: Length of number array
  *
@@ -821,11 +821,12 @@ regress_annotation_return_filename (void)
 
 /**
  * regress_annotation_transfer_floating:
+ * @object: (in) (transfer floating): an object
  *
  * Returns: (transfer floating): A floating object
  */
 GObject *
-regress_annotation_transfer_floating(void)
+regress_annotation_transfer_floating (GObject *object)
 {
   return NULL;
 }
